pub struct AsinhCodec {
pub linear_width: f64,
pub version: StaticCodecVersion<1, 0, 0>,
}Expand description
Asinh codec, which applies a quasi-logarithmic transformation on encoding.
For values close to zero that are within the codec’s linear_width, the
transform is close to linear. For values of larger magnitudes, the
transform is asymptotically logarithmic. Unlike a logarithmic transform,
this codec supports all finite values, including negative values and zero.
In detail, the codec calculates
$c = w \cdot \text{asinh}\left( \frac{x}{w} \right)$
on encoding and
$d = w \cdot \text{sinh}\left( \frac{c}{w} \right)$
on decoding, where $w$ is the codec’s linear_width.
The codec only supports finite floating point numbers.
Fields
linear_width: f64The width of the close-to-zero input value range where the transform is nearly linear
version: StaticCodecVersion<1, 0, 0>The codec’s encoding format version. Do not provide this parameter explicitly.